==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/language/1/barnraiser_01/me_identity.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');
include_once($language_path . 'inc/identity_common.inc.php');

// HEADERS
$lang['hdr_identities'] = 							"identity cards";
$lang['hdr_identity_creator'] = 					"identity creator";
$lang['hdr_identity_intro'] = 						"identity intro";



// HREF
$lang['href_identity_add'] = 						"add a card";
$lang['href_identity_edit'] = 						"edit this card";


// SUBMIT
$lang['sub_update_identity'] = 						"update identity";
$lang['sub_delete_identity'] = 						"delete identity";


// TEXTS
$lang['txt_identity_intro'] = 						"An identity card is like a business card. It allows you to present yourself to other people. You can make many cards. One is always reserved for other registered members to see and one for the public to see. <b>We recommend that you never display personal information in your public card</b>.";
$lang['txt_identity_name'] = 						"name";
$lang['txt_gender'] = 								"gender";
$lang['txt_female'] = 								"female";
$lang['txt_male'] = 								"male";
$lang['txt_none'] = 								"none";
$lang['txt_undisclosed'] = 							"undisclosed";
$lang['txt_nic'] = 									"nic";
$lang['txt_message'] = 								"allow people who read this card to send you a message?";
$lang['txt_export'] = 								"allow people who read this card to export the card details?";
$lang['txt_space'] = 								"add my personal space link into this card?";
$lang['txt_identity_type_member'] = 				"make this card my membership card";
$lang['txt_identity_type_public'] = 				"make this card my public card";
$lang['txt_identity_type'] = 						"card type";
$lang['txt_preferences'] = 							"card preferences";
$lang['txt_signature'] = 							"signature";
$lang['txt_card'] = 								"card";
$lang['txt_image'] = 								"picture";
$lang['txt_none'] = 								"none";
$lang['txt_image_help'] = 							"You can add a picture to your selector by going to 'files' and uploading one.";
$lang['txt_identity_spare'] =	 					"spare card";
$lang['txt_search'] =								"allow people to search on this identity card?";

?>

==> aroundme_0_7_7.zip: aroundme_0_7_7/aroundme/components/core/language/1/barnraiser_01/me_identity.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');
include_once($language_path . 'inc/identity_common.inc.php');

// HEADERS
$lang['hdr_identities'] = 							"identity cards";
$lang['hdr_identity_creator'] = 					"identity creator";
$lang['hdr_identity_intro'] = 						"identity intro";




// HREF
$lang['href_identity_add'] = 						"add a card";
$lang['href_identity_edit'] = 						"edit this card";


// SUBMIT
$lang['sub_update_identity'] = 						"update identity";


// TEXTS
$lang['txt_identity_intro'] = 						"An identity card is like a business card. It allows you to present yourself to other people. You can make many cards. One is always reserved for other registered members to see and one for the public to see. <b>We recommend that you never display personal information in your public card</b>.";
$lang['txt_identity_name'] = 						"name";
$lang['txt_gender'] = 								"gender";
$lang['txt_female'] = 								"female";
$lang['txt_male'] = 								"male";
$lang['txt_none'] = 								"none";
$lang['txt_undisclosed'] = 							"undisclosed";
$lang['txt_nic'] = 									"nic";
$lang['txt_message'] = 								"allow people who read this card to send you a message?";
$lang['txt_export'] = 								"allow people who read this card to export the card details?";
$lang['txt_identity_type_member'] = 				"make this card my membership card";
$lang['txt_identity_type_public'] = 				"make this card my public card";
$lang['txt_identity_type'] = 						"card type";
$lang['txt_preferences'] = 							"card preferences";
$lang['txt_signature'] = 							"signature";
$lang['txt_card'] = 								"card";
$lang['txt_image'] = 								"picture";
$lang['txt_none'] = 								"none";
$lang['txt_image_help'] = 							"You can add a picture to your selector by going to 'files' and uploading one.";
$lang['txt_identity_spare'] =	 					"spare card";
$lang['txt_search'] =								"allow people to search on this identity card?";
$lang['txt_metadata'] =								"search words";
$lang['txt_metadata_intro'] =						"Type in words separated by a comma that describe you. This will be used for other members when searching for people.";
$lang['txt_activate_identity'] = 					"Make this card appear on my identity selector";
$lang['txt_activate'] =								"activate card";
?>
